{
    "$graph": [
        {
            "class": "Workflow",
            "label": "STAR-RNA-Seq alignment and transcript/gene abundance workflow",
            "requirements": [
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "type": "record",
                            "name": "#sequence_data.yml/sequence_data",
                            "label": "sequence data with readgroup information",
                            "fields": [
                                {
                                    "type": [
                                        "null",
                                        "string"
                                    ],
                                    "name": "#sequence_data.yml/sequence_data/readgroup"
                                },
                                {
                                    "type": [
                                        {
                                            "type": "record",
                                            "name": "#sequence_data.yml/sequence_data/sequence/bam",
                                            "fields": [
                                                {
                                                    "type": "File",
                                                    "name": "#sequence_data.yml/sequence_data/sequence/bam/bam"
                                                }
                                            ]
                                        },
                                        {
                                            "type": "record",
                                            "name": "#sequence_data.yml/sequence_data/sequence/fastqs",
                                            "fields": [
                                                {
                                                    "type": "File",
                                                    "name": "#sequence_data.yml/sequence_data/sequence/fastqs/fastq1"
                                                },
                                                {
                                                    "type": "File",
                                                    "name": "#sequence_data.yml/sequence_data/sequence/fastqs/fastq2"
                                                }
                                            ]
                                        }
                                    ],
                                    "name": "#sequence_data.yml/sequence_data/sequence"
                                }
                            ]
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/cdna_fasta"
                },
                {
                    "type": "File",
                    "id": "#main/gene_transcript_lookup_table"
                },
                {
                    "type": "File",
                    "id": "#main/gtf_file"
                },
                {
                    "type": "File",
                    "id": "#main/kallisto_index"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#main/outsam_attrrg_line"
                },
                {
                    "type": "File",
                    "id": "#main/refFlat"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#main/reference"
                },
                {
                    "type": "File",
                    "id": "#main/ribosomal_intervals"
                },
                {
                    "type": "string",
                    "id": "#main/sample_name"
                },
                {
                    "type": "Directory",
                    "id": "#main/star_fusion_genome_dir"
                },
                {
                    "type": "Directory",
                    "id": "#main/star_genome_dir"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#main/strand/first",
                                "#main/strand/second",
                                "#main/strand/unstranded"
                            ]
                        }
                    ],
                    "id": "#main/strand"
                },
                {
                    "type": "int",
                    "id": "#main/trimming_adapter_min_overlap"
                },
                {
                    "type": "string",
                    "id": "#main/trimming_adapter_trim_end"
                },
                {
                    "type": "File",
                    "id": "#main/trimming_adapters"
                },
                {
                    "type": "int",
                    "id": "#main/trimming_max_uncalled"
                },
                {
                    "type": "int",
                    "id": "#main/trimming_min_readlength"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "#sequence_data.yml/sequence_data"
                    },
                    "id": "#main/unaligned"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "id": "#main/unzip_fastqs"
                }
            ],
            "steps": [
                {
                    "run": "#bam_to_cram.cwl",
                    "in": [
                        {
                            "source": "#main/index_bam/indexed_bam",
                            "id": "#main/bam_to_cram/bam"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/bam_to_cram/reference"
                        }
                    ],
                    "out": [
                        "#main/bam_to_cram/cram"
                    ],
                    "id": "#main/bam_to_cram"
                },
                {
                    "run": "#bam_to_bigwig.cwl",
                    "in": [
                        {
                            "source": "#main/mark_dup/sorted_bam",
                            "id": "#main/cgpbigwig_bamcoverage/bam"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/cgpbigwig_bamcoverage/reference"
                        }
                    ],
                    "out": [
                        "#main/cgpbigwig_bamcoverage/outfile"
                    ],
                    "id": "#main/cgpbigwig_bamcoverage"
                },
                {
                    "run": "#generate_qc_metrics.cwl",
                    "in": [
                        {
                            "source": "#main/mark_dup/sorted_bam",
                            "id": "#main/generate_qc_metrics/bam"
                        },
                        {
                            "source": "#main/refFlat",
                            "id": "#main/generate_qc_metrics/refFlat"
                        },
                        {
                            "source": "#main/ribosomal_intervals",
                            "id": "#main/generate_qc_metrics/ribosomal_intervals"
                        },
                        {
                            "source": "#main/strand",
                            "id": "#main/generate_qc_metrics/strand"
                        }
                    ],
                    "out": [
                        "#main/generate_qc_metrics/metrics",
                        "#main/generate_qc_metrics/chart"
                    ],
                    "id": "#main/generate_qc_metrics"
                },
                {
                    "run": "#index_bam.cwl",
                    "in": [
                        {
                            "source": "#main/mark_dup/sorted_bam",
                            "id": "#main/index_bam/bam"
                        }
                    ],
                    "out": [
                        "#main/index_bam/indexed_bam"
                    ],
                    "id": "#main/index_bam"
                },
                {
                    "run": "#index_cram.cwl",
                    "in": [
                        {
                            "source": "#main/bam_to_cram/cram",
                            "id": "#main/index_cram/cram"
                        }
                    ],
                    "out": [
                        "#main/index_cram/indexed_cram"
                    ],
                    "id": "#main/index_cram"
                },
                {
                    "run": "#kallisto.cwl",
                    "in": [
                        {
                            "source": "#main/sequence_to_trimmed_fastq/fastqs",
                            "id": "#main/kallisto/fastqs"
                        },
                        {
                            "source": "#main/kallisto_index",
                            "id": "#main/kallisto/kallisto_index"
                        },
                        {
                            "source": "#main/strand",
                            "id": "#main/kallisto/strand"
                        }
                    ],
                    "out": [
                        "#main/kallisto/expression_transcript_table",
                        "#main/kallisto/expression_transcript_h5",
                        "#main/kallisto/fusion_evidence"
                    ],
                    "id": "#main/kallisto"
                },
                {
                    "run": "#mark_duplicates_and_sort.cwl",
                    "in": [
                        {
                            "source": "#main/sort_bam/sorted_bam",
                            "id": "#main/mark_dup/bam"
                        },
                        {
                            "default": "coordinate",
                            "id": "#main/mark_dup/input_sort_order"
                        }
                    ],
                    "out": [
                        "#main/mark_dup/sorted_bam",
                        "#main/mark_dup/metrics_file"
                    ],
                    "id": "#main/mark_dup"
                },
                {
                    "scatter": [
                        "#main/sequence_to_trimmed_fastq/unaligned"
                    ],
                    "scatterMethod": "dotproduct",
                    "run": "#sequence_to_trimmed_fastq.cwl",
                    "in": [
                        {
                            "source": "#main/trimming_adapter_min_overlap",
                            "id": "#main/sequence_to_trimmed_fastq/adapter_min_overlap"
                        },
                        {
                            "source": "#main/trimming_adapter_trim_end",
                            "id": "#main/sequence_to_trimmed_fastq/adapter_trim_end"
                        },
                        {
                            "source": "#main/trimming_adapters",
                            "id": "#main/sequence_to_trimmed_fastq/adapters"
                        },
                        {
                            "source": "#main/trimming_max_uncalled",
                            "id": "#main/sequence_to_trimmed_fastq/max_uncalled"
                        },
                        {
                            "source": "#main/trimming_min_readlength",
                            "id": "#main/sequence_to_trimmed_fastq/min_readlength"
                        },
                        {
                            "source": "#main/unaligned",
                            "id": "#main/sequence_to_trimmed_fastq/unaligned"
                        },
                        {
                            "source": "#main/unzip_fastqs",
                            "id": "#main/sequence_to_trimmed_fastq/unzip_fastqs"
                        }
                    ],
                    "out": [
                        "#main/sequence_to_trimmed_fastq/fastqs",
                        "#main/sequence_to_trimmed_fastq/fastq1",
                        "#main/sequence_to_trimmed_fastq/fastq2"
                    ],
                    "id": "#main/sequence_to_trimmed_fastq"
                },
                {
                    "run": "#samtools_sort.cwl",
                    "in": [
                        {
                            "source": "#main/star_align_fusion/aligned_bam",
                            "id": "#main/sort_bam/input_bam"
                        }
                    ],
                    "out": [
                        "#main/sort_bam/sorted_bam"
                    ],
                    "id": "#main/sort_bam"
                },
                {
                    "run": "#star_align_fusion.cwl",
                    "in": [
                        {
                            "source": "#main/sequence_to_trimmed_fastq/fastq1",
                            "linkMerge": "merge_flattened",
                            "id": "#main/star_align_fusion/fastq"
                        },
                        {
                            "source": "#main/sequence_to_trimmed_fastq/fastq2",
                            "linkMerge": "merge_flattened",
                            "id": "#main/star_align_fusion/fastq2"
                        },
                        {
                            "source": "#main/gtf_file",
                            "id": "#main/star_align_fusion/gtf_file"
                        },
                        {
                            "source": "#main/outsam_attrrg_line",
                            "id": "#main/star_align_fusion/outsam_attrrg_line"
                        },
                        {
                            "source": "#main/star_genome_dir",
                            "id": "#main/star_align_fusion/star_genome_dir"
                        }
                    ],
                    "out": [
                        "#main/star_align_fusion/aligned_bam",
                        "#main/star_align_fusion/chim_junc",
                        "#main/star_align_fusion/splice_junction_out",
                        "#main/star_align_fusion/log_final"
                    ],
                    "id": "#main/star_align_fusion"
                },
                {
                    "run": "#star_fusion_detect.cwl",
                    "in": [
                        {
                            "source": "#main/star_align_fusion/chim_junc",
                            "id": "#main/star_fusion_detect/junction_file"
                        },
                        {
                            "source": "#main/star_fusion_genome_dir",
                            "id": "#main/star_fusion_detect/star_fusion_genome_dir"
                        }
                    ],
                    "out": [
                        "#main/star_fusion_detect/fusion_predictions",
                        "#main/star_fusion_detect/fusion_abridged"
                    ],
                    "id": "#main/star_fusion_detect"
                },
                {
                    "run": "#strandedness_check.cwl",
                    "scatter": [
                        "#main/strandedness_check/reads1",
                        "#main/strandedness_check/reads2"
                    ],
                    "scatterMethod": "dotproduct",
                    "in": [
                        {
                            "source": "#main/cdna_fasta",
                            "id": "#main/strandedness_check/cdna_fasta"
                        },
                        {
                            "source": "#main/gtf_file",
                            "id": "#main/strandedness_check/gtf_file"
                        },
                        {
                            "source": "#main/kallisto_index",
                            "id": "#main/strandedness_check/kallisto_index"
                        },
                        {
                            "source": "#main/sequence_to_trimmed_fastq/fastq1",
                            "id": "#main/strandedness_check/reads1"
                        },
                        {
                            "source": "#main/sequence_to_trimmed_fastq/fastq2",
                            "id": "#main/strandedness_check/reads2"
                        }
                    ],
                    "out": [
                        "#main/strandedness_check/strandedness_check"
                    ],
                    "id": "#main/strandedness_check"
                },
                {
                    "run": "#stringtie.cwl",
                    "in": [
                        {
                            "source": "#main/mark_dup/sorted_bam",
                            "id": "#main/stringtie/bam"
                        },
                        {
                            "source": "#main/gtf_file",
                            "id": "#main/stringtie/reference_annotation"
                        },
                        {
                            "source": "#main/sample_name",
                            "id": "#main/stringtie/sample_name"
                        },
                        {
                            "source": "#main/strand",
                            "id": "#main/stringtie/strand"
                        }
                    ],
                    "out": [
                        "#main/stringtie/transcript_gtf",
                        "#main/stringtie/gene_expression_tsv"
                    ],
                    "id": "#main/stringtie"
                },
                {
                    "run": "#transcript_to_gene.cwl",
                    "in": [
                        {
                            "source": "#main/gene_transcript_lookup_table",
                            "id": "#main/transcript_to_gene/gene_transcript_lookup_table"
                        },
                        {
                            "source": "#main/kallisto/expression_transcript_h5",
                            "id": "#main/transcript_to_gene/transcript_table_h5"
                        }
                    ],
                    "out": [
                        "#main/transcript_to_gene/gene_abundance"
                    ],
                    "id": "#main/transcript_to_gene"
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/cgpbigwig_bamcoverage/outfile",
                    "id": "#main/bamcoverage_bigwig"
                },
                {
                    "type": "File",
                    "outputSource": "#main/generate_qc_metrics/chart",
                    "id": "#main/chart"
                },
                {
                    "type": "File",
                    "outputSource": "#main/index_cram/indexed_cram",
                    "secondaryFiles": [
                        ".crai",
                        "^.crai"
                    ],
                    "id": "#main/cram"
                },
                {
                    "type": "File",
                    "outputSource": "#main/kallisto/fusion_evidence",
                    "id": "#main/fusion_evidence"
                },
                {
                    "type": "File",
                    "outputSource": "#main/transcript_to_gene/gene_abundance",
                    "id": "#main/gene_abundance"
                },
                {
                    "type": "File",
                    "outputSource": "#main/generate_qc_metrics/metrics",
                    "id": "#main/metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/star_fusion_detect/fusion_abridged",
                    "id": "#main/star_fusion_abridge"
                },
                {
                    "type": "File",
                    "outputSource": "#main/star_align_fusion/log_final",
                    "id": "#main/star_fusion_log"
                },
                {
                    "type": "File",
                    "outputSource": "#main/star_align_fusion/chim_junc",
                    "id": "#main/star_fusion_out"
                },
                {
                    "type": "File",
                    "outputSource": "#main/star_fusion_detect/fusion_predictions",
                    "id": "#main/star_fusion_predict"
                },
                {
                    "type": "File",
                    "outputSource": "#main/star_align_fusion/splice_junction_out",
                    "id": "#main/star_junction_out"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/strandedness_check/strandedness_check",
                    "id": "#main/strand_info"
                },
                {
                    "type": "File",
                    "outputSource": "#main/stringtie/gene_expression_tsv",
                    "id": "#main/stringtie_gene_expression_tsv"
                },
                {
                    "type": "File",
                    "outputSource": "#main/stringtie/transcript_gtf",
                    "id": "#main/stringtie_transcript_gtf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/kallisto/expression_transcript_h5",
                    "id": "#main/transcript_abundance_h5"
                },
                {
                    "type": "File",
                    "outputSource": "#main/kallisto/expression_transcript_table",
                    "id": "#main/transcript_abundance_tsv"
                }
            ]
        },
        {
            "class": "Workflow",
            "label": "sequence (bam or fastqs) to trimmed fastqs",
            "requirements": [
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "$import": "#sequence_data.yml/sequence_data"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "int",
                    "id": "#sequence_to_trimmed_fastq.cwl/adapter_min_overlap"
                },
                {
                    "type": "string",
                    "id": "#sequence_to_trimmed_fastq.cwl/adapter_trim_end"
                },
                {
                    "type": "File",
                    "id": "#sequence_to_trimmed_fastq.cwl/adapters"
                },
                {
                    "type": "int",
                    "id": "#sequence_to_trimmed_fastq.cwl/max_uncalled"
                },
                {
                    "type": "int",
                    "id": "#sequence_to_trimmed_fastq.cwl/min_readlength"
                },
                {
                    "type": "#sequence_data.yml/sequence_data",
                    "id": "#sequence_to_trimmed_fastq.cwl/unaligned"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "id": "#sequence_to_trimmed_fastq.cwl/unzip_fastqs"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#sequence_to_trimmed_fastq.cwl/trim_fastq/fastq1",
                    "id": "#sequence_to_trimmed_fastq.cwl/fastq1"
                },
                {
                    "type": "File",
                    "outputSource": "#sequence_to_trimmed_fastq.cwl/trim_fastq/fastq2",
                    "id": "#sequence_to_trimmed_fastq.cwl/fastq2"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#sequence_to_trimmed_fastq.cwl/trim_fastq/fastqs",
                    "id": "#sequence_to_trimmed_fastq.cwl/fastqs"
                }
            ],
            "steps": [
                {
                    "run": "#sequence_to_fastq.cwl",
                    "in": [
                        {
                            "source": "#sequence_to_trimmed_fastq.cwl/unaligned",
                            "valueFrom": "$(self.sequence.hasOwnProperty('bam')? self.sequence.bam : null)",
                            "id": "#sequence_to_trimmed_fastq.cwl/sequence_to_fastq/bam"
                        },
                        {
                            "source": "#sequence_to_trimmed_fastq.cwl/unaligned",
                            "valueFrom": "$(self.sequence.hasOwnProperty('fastq1')? self.sequence.fastq1 : null)",
                            "id": "#sequence_to_trimmed_fastq.cwl/sequence_to_fastq/fastq1"
                        },
                        {
                            "source": "#sequence_to_trimmed_fastq.cwl/unaligned",
                            "valueFrom": "$(self.sequence.hasOwnProperty('fastq2')? self.sequence.fastq2 : null)",
                            "id": "#sequence_to_trimmed_fastq.cwl/sequence_to_fastq/fastq2"
                        },
                        {
                            "source": "#sequence_to_trimmed_fastq.cwl/unzip_fastqs",
                            "id": "#sequence_to_trimmed_fastq.cwl/sequence_to_fastq/unzip_fastqs"
                        }
                    ],
                    "out": [
                        "#sequence_to_trimmed_fastq.cwl/sequence_to_fastq/fastq1",
                        "#sequence_to_trimmed_fastq.cwl/sequence_to_fastq/fastq2"
                    ],
                    "id": "#sequence_to_trimmed_fastq.cwl/sequence_to_fastq"
                },
                {
                    "run": "#trim_fastq.cwl",
                    "in": [
                        {
                            "source": "#sequence_to_trimmed_fastq.cwl/adapter_min_overlap",
                            "id": "#sequence_to_trimmed_fastq.cwl/trim_fastq/adapter_min_overlap"
                        },
                        {
                            "source": "#sequence_to_trimmed_fastq.cwl/adapter_trim_end",
                            "id": "#sequence_to_trimmed_fastq.cwl/trim_fastq/adapter_trim_end"
                        },
                        {
                            "source": "#sequence_to_trimmed_fastq.cwl/adapters",
                            "id": "#sequence_to_trimmed_fastq.cwl/trim_fastq/adapters"
                        },
                        {
                            "source": "#sequence_to_trimmed_fastq.cwl/max_uncalled",
                            "id": "#sequence_to_trimmed_fastq.cwl/trim_fastq/max_uncalled"
                        },
                        {
                            "source": "#sequence_to_trimmed_fastq.cwl/min_readlength",
                            "id": "#sequence_to_trimmed_fastq.cwl/trim_fastq/min_readlength"
                        },
                        {
                            "source": "#sequence_to_trimmed_fastq.cwl/sequence_to_fastq/fastq1",
                            "id": "#sequence_to_trimmed_fastq.cwl/trim_fastq/reads1"
                        },
                        {
                            "source": "#sequence_to_trimmed_fastq.cwl/sequence_to_fastq/fastq2",
                            "id": "#sequence_to_trimmed_fastq.cwl/trim_fastq/reads2"
                        }
                    ],
                    "out": [
                        "#sequence_to_trimmed_fastq.cwl/trim_fastq/fastqs",
                        "#sequence_to_trimmed_fastq.cwl/trim_fastq/fastq1",
                        "#sequence_to_trimmed_fastq.cwl/trim_fastq/fastq2"
                    ],
                    "id": "#sequence_to_trimmed_fastq.cwl/trim_fastq"
                }
            ],
            "id": "#sequence_to_trimmed_fastq.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "cgpBigWig Converting BAM to BigWig",
            "baseCommand": [
                "bam2bw",
                "-a",
                "-F",
                "1024"
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(inputs.bam.nameroot).bw"
                }
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/biocontainers/cgpbigwig:1.4.0--h93d22ca_0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 32000
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-i"
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#bam_to_bigwig.cwl/bam"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-r"
                    },
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#bam_to_bigwig.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bam.nameroot).bw"
                    },
                    "id": "#bam_to_bigwig.cwl/outfile"
                }
            ],
            "id": "#bam_to_bigwig.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "BAM to CRAM conversion",
            "baseCommand": [
                "/usr/local/bin/samtools",
                "view",
                "-C"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/biocontainers/samtools:1.11--h6270b1f_0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "stdout": "$(inputs.bam.nameroot).cram",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#bam_to_cram.cwl/bam"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "-T",
                        "position": 1
                    },
                    "id": "#bam_to_cram.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#bam_to_cram.cwl/cram",
                    "outputBinding": {
                        "glob": "$(inputs.bam.nameroot).cram"
                    }
                }
            ],
            "id": "#bam_to_cram.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Picard: RNA Seq Metrics",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/opt/picard/picard.jar",
                "CollectRnaSeqMetrics"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 18000,
                    "coresMin": 1
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/rnaseq:1.0.0"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "O=$(runtime.outdir)/rna_metrics.txt"
                },
                {
                    "valueFrom": "CHART=$(runtime.outdir)/rna_metrics.pdf"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "I=",
                        "separate": false
                    },
                    "id": "#generate_qc_metrics.cwl/bam"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "REF_FLAT=",
                        "separate": false
                    },
                    "id": "#generate_qc_metrics.cwl/refFlat"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "RIBOSOMAL_INTERVALS=",
                        "separate": false
                    },
                    "id": "#generate_qc_metrics.cwl/ribosomal_intervals"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#generate_qc_metrics.cwl/strand/first",
                                "#generate_qc_metrics.cwl/strand/second",
                                "#generate_qc_metrics.cwl/strand/unstranded"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "valueFrom": "${\n    if (inputs.strand) {\n        if (inputs.strand == 'first') {  \n            return ['STRAND=SECOND_READ_TRANSCRIPTION_STRAND'];\n        } else if (inputs.strand == 'second') {\n            return ['STRAND=FIRST_READ_TRANSCRIPTION_STRAND'];\n        } else {\n            return ['STRAND=NONE'];\n        }\n    } else {\n            return ['STRAND=NONE']\n    }\n}\n"
                    },
                    "id": "#generate_qc_metrics.cwl/strand"
                }
            ],
            "outputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "rna_metrics.pdf"
                    },
                    "id": "#generate_qc_metrics.cwl/chart"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "rna_metrics.txt"
                    },
                    "id": "#generate_qc_metrics.cwl/metrics"
                }
            ],
            "id": "#generate_qc_metrics.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "samtools index",
            "arguments": [
                "/usr/local/bin/samtools",
                "index",
                "$(runtime.outdir)/$(inputs.bam.basename)",
                "$(runtime.outdir)/$(inputs.bam.basename).bai",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "cp",
                "$(inputs.bam.basename).bai",
                "$(runtime.outdir)/$(inputs.bam.nameroot).bai"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/biocontainers/samtools:1.11--h6270b1f_0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        "${ var f = inputs.bam; delete f.secondaryFiles; return f }"
                    ]
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#index_bam.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".bai",
                        "^.bai"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.bam.basename)"
                    },
                    "id": "#index_bam.cwl/indexed_bam"
                }
            ],
            "id": "#index_bam.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "samtools index cram",
            "arguments": [
                "/usr/local/bin/samtools",
                "index",
                "$(runtime.outdir)/$(inputs.cram.basename)",
                "$(runtime.outdir)/$(inputs.cram.basename).crai",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "cp",
                "$(inputs.cram.basename).crai",
                "$(runtime.outdir)/$(inputs.cram.nameroot).crai"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/biocontainers/samtools:1.11--h6270b1f_0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        "${ var f = inputs.cram; delete f.secondaryFiles; return f }"
                    ]
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#index_cram.cwl/cram"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".crai",
                        "^.crai"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.cram.basename)"
                    },
                    "id": "#index_cram.cwl/indexed_cram"
                }
            ],
            "id": "#index_cram.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Kallisto: Quant",
            "baseCommand": [
                "kallisto"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 32000,
                    "coresMin": 8
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/biocontainers/kallisto:0.46.1--h4f7b962_0"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "arguments": [
                "quant",
                "-t",
                "$(runtime.cores)",
                "-b",
                "100",
                "--fusion",
                "-o",
                "kallisto"
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": {
                            "type": "array",
                            "items": "File"
                        }
                    },
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#kallisto.cwl/fastqs"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-i",
                        "position": 2
                    },
                    "id": "#kallisto.cwl/kallisto_index"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#kallisto.cwl/strand/first",
                                "#kallisto.cwl/strand/second",
                                "#kallisto.cwl/strand/unstranded"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "valueFrom": "${\n    if (inputs.strand) {\n        if (inputs.strand == 'first') {\n            return ['--rf-stranded'];\n        } else if (inputs.strand == 'second') {\n            return ['--fr-stranded'];\n        } else {\n            return [];\n        }\n    } else {\n            return [];\n    }\n}\n",
                        "position": 1
                    },
                    "id": "#kallisto.cwl/strand"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "kallisto/abundance.h5"
                    },
                    "id": "#kallisto.cwl/expression_transcript_h5"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "kallisto/abundance.tsv"
                    },
                    "id": "#kallisto.cwl/expression_transcript_table"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "kallisto/fusion.txt"
                    },
                    "id": "#kallisto.cwl/fusion_evidence"
                }
            ],
            "id": "#kallisto.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Mark duplicates and Sort",
            "baseCommand": [
                "/bin/bash",
                "markduplicates_helper.sh"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "coresMin": 8,
                    "ramMin": 40000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/mark_duplicates-cwl:1.0.1"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "markduplicates_helper.sh",
                            "entry": "set -o pipefail\nset -o errexit\n\ndeclare MD_BARCODE_TAG\nif [ ! -z \"$6\" ]; then\n  MD_BARCODE_TAG=\"BARCODE_TAG=$6\"\n/usr/bin/java -Xmx16g -jar /opt/picard/picard.jar MarkDuplicates I=$1 O=/dev/stdout ASSUME_SORT_ORDER=$5 METRICS_FILE=$4 QUIET=true COMPRESSION_LEVEL=0 VALIDATION_STRINGENCY=LENIENT \"$MD_BARCODE_TAG\" | /usr/bin/sambamba sort -t $2 -m 18G -o $3 /dev/stdin\nelse\n  /usr/bin/java -Xmx16g -jar /opt/picard/picard.jar MarkDuplicates I=$1 O=/dev/stdout ASSUME_SORT_ORDER=$5 METRICS_FILE=$4 QUIET=true COMPRESSION_LEVEL=0 VALIDATION_STRINGENCY=LENIENT | /usr/bin/sambamba sort -t $2 -m 18G -o $3 /dev/stdin\nfi\n"
                        }
                    ]
                }
            ],
            "arguments": [
                {
                    "position": 2,
                    "valueFrom": "$(runtime.cores)"
                },
                {
                    "position": 4,
                    "valueFrom": "$(inputs.bam.nameroot).mark_dups_metrics.txt"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#mark_duplicates_and_sort.cwl/bam"
                },
                {
                    "type": "string",
                    "default": "queryname",
                    "inputBinding": {
                        "position": 5
                    },
                    "id": "#mark_duplicates_and_sort.cwl/input_sort_order"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "MarkedSorted.bam",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#mark_duplicates_and_sort.cwl/output_name"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bam.nameroot).mark_dups_metrics.txt"
                    },
                    "id": "#mark_duplicates_and_sort.cwl/metrics_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_name)"
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#mark_duplicates_and_sort.cwl/sorted_bam"
                }
            ],
            "id": "#mark_duplicates_and_sort.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "samtools sort",
            "baseCommand": [
                "/usr/local/bin/samtools",
                "sort"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000,
                    "coresMin": 1
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/biocontainers/samtools:1.11--h6270b1f_0"
                }
            ],
            "arguments": [
                {
                    "prefix": "-o",
                    "valueFrom": "$(runtime.outdir)/$(inputs.output_filename)"
                },
                {
                    "prefix": "-@",
                    "valueFrom": "$(runtime.cores)"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 50
                    },
                    "id": "#samtools_sort.cwl/input_bam"
                },
                {
                    "type": "string",
                    "default": "sorted.bam",
                    "id": "#samtools_sort.cwl/output_filename"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_filename)"
                    },
                    "id": "#samtools_sort.cwl/sorted_bam"
                }
            ],
            "id": "#samtools_sort.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Picard: BAM to FASTQ",
            "baseCommand": [
                "/bin/bash",
                "makefastqs.sh"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "coresMin": 1,
                    "ramMin": 16000,
                    "tmpdirMin": 25000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "broadinstitute/picard:2.23.6"
                },
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "$import": "#sequence_data.yml/sequence_data"
                        }
                    ]
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "makefastqs.sh",
                            "entry": "set -o pipefail\nset -o errexit\nset -o nounset\n\nUNZIP=false\n\nwhile getopts \":b:1:2:d:u\" opt; do\n    case \"$opt\" in\n        b)\n            MODE=bam\n            BAM=\"$OPTARG\"\n            ;;\n        1)\n            MODE=fastq\n            FASTQ1=\"$OPTARG\"\n            ;;\n        2)  \n            MODE=fastq\n            FASTQ2=\"$OPTARG\"\n            ;;\n        d)\n            OUTDIR=\"$OPTARG\"\n            ;;\n        u)\n            UNZIP=true\n            ;;\n    esac\ndone\n\nif [[ \"$MODE\" == 'fastq' ]]; then #must be fastq input\n\n    if $UNZIP; then\n        if gzip -t $FASTQ1 2> /dev/null; then\n            gunzip -c $FASTQ1 > $OUTDIR/read1.fastq\n        else\n            cp $FASTQ1 $OUTDIR/read1.fastq\n        fi\n\n        if gzip -t $FASTQ2 2> /dev/null; then\n            gunzip -c $FASTQ2 > $OUTDIR/read2.fastq\n        else\n            cp $FASTQ2 $OUTDIR/read2.fastq\n        fi\n    else\n        if gzip -t $FASTQ1 2> /dev/null; then\n            cp $FASTQ1 $OUTDIR/read1.fastq.gz\n        else\n            cp $FASTQ1 $OUTDIR/read1.fastq\n        fi\n\n        if gzip -t $FASTQ2 2> /dev/null; then\n            cp $FASTQ2 $OUTDIR/read2.fastq.gz\n        else\n            cp $FASTQ2 $OUTDIR/read2.fastq\n        fi\n    fi\n\nelse # then\n    ##run samtofastq here, dumping to the same filenames\n    ## input file is $BAM\n    /usr/bin/java -Xmx4g -jar /usr/picard/picard.jar SamToFastq I=\"$BAM\" INCLUDE_NON_PF_READS=true F=$OUTDIR/read1.fastq F2=$OUTDIR/read2.fastq VALIDATION_STRINGENCY=SILENT\nfi\n"
                        }
                    ]
                }
            ],
            "arguments": [
                {
                    "valueFrom": "$(runtime.outdir)",
                    "position": -6,
                    "prefix": "-d"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-b"
                    },
                    "id": "#sequence_to_fastq.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-1"
                    },
                    "id": "#sequence_to_fastq.cwl/fastq1"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-2"
                    },
                    "id": "#sequence_to_fastq.cwl/fastq2"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "-u"
                    },
                    "doc": "If true, and the input sequence contains gzipped fastqs, they will be unzipped",
                    "id": "#sequence_to_fastq.cwl/unzip_fastqs"
                }
            ],
            "outputs": [
                {
                    "$import": "#sequence_to_fastq.cwl/fastq1"
                },
                {
                    "$import": "#sequence_to_fastq.cwl/fastq2"
                }
            ],
            "id": "#sequence_to_fastq.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "STAR: align reads to transcriptome",
            "baseCommand": [
                "/usr/local/bin/STAR"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 64000,
                    "coresMin": 10
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/star:2.7.0f"
                }
            ],
            "arguments": [
                "--runThreadN",
                "$(runtime.cores)"
            ],
            "inputs": [
                {
                    "type": "int",
                    "default": 100000,
                    "inputBinding": {
                        "position": 11,
                        "prefix": "--alignIntronMax"
                    },
                    "id": "#star_align_fusion.cwl/align_intron_max"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 100000,
                    "inputBinding": {
                        "position": 10,
                        "prefix": "--alignMatesGapMax"
                    },
                    "id": "#star_align_fusion.cwl/align_mates_gapmax"
                },
                {
                    "type": "int",
                    "default": 10,
                    "inputBinding": {
                        "position": 9,
                        "prefix": "--alignSJDBoverhangMin"
                    },
                    "id": "#star_align_fusion.cwl/align_sjdb_overhang_min"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "int"
                    },
                    "default": [
                        5,
                        -1,
                        5,
                        5
                    ],
                    "inputBinding": {
                        "position": 13,
                        "prefix": "--alignSJstitchMismatchNmax",
                        "itemSeparator": " ",
                        "shellQuote": false
                    },
                    "id": "#star_align_fusion.cwl/align_sjstitch_mismatch_nmax"
                },
                {
                    "type": "int",
                    "default": "12",
                    "inputBinding": {
                        "position": 8,
                        "prefix": "--chimJunctionOverhangMin"
                    },
                    "id": "#star_align_fusion.cwl/chim_junction_overhang_min"
                },
                {
                    "type": "int",
                    "default": 10,
                    "inputBinding": {
                        "position": 17,
                        "prefix": "--chimMultimapNmax"
                    },
                    "id": "#star_align_fusion.cwl/chim_multimap_nmax"
                },
                {
                    "type": "int",
                    "default": 10,
                    "inputBinding": {
                        "position": 18,
                        "prefix": "--chimNonchimScoreDropMin"
                    },
                    "id": "#star_align_fusion.cwl/chim_nonchim_scoredrop_min"
                },
                {
                    "type": "int",
                    "default": "12",
                    "inputBinding": {
                        "position": 7,
                        "prefix": "--chimSegmentMin"
                    },
                    "id": "#star_align_fusion.cwl/chim_segment_min"
                },
                {
                    "type": "int",
                    "default": 3,
                    "inputBinding": {
                        "position": 12,
                        "prefix": "--chimSegmentReadGapMax"
                    },
                    "id": "#star_align_fusion.cwl/chim_segment_read_gapmax"
                },
                {
                    "type": "int",
                    "default": 1,
                    "inputBinding": {
                        "position": 21,
                        "prefix": "--chimOutJunctionFormat"
                    },
                    "id": "#star_align_fusion.cwl/chimout_junction_format"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--readFilesIn",
                        "itemSeparator": ","
                    },
                    "id": "#star_align_fusion.cwl/fastq"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 5,
                        "itemSeparator": ","
                    },
                    "id": "#star_align_fusion.cwl/fastq2"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 24,
                        "prefix": "--sjdbGTFfile"
                    },
                    "id": "#star_align_fusion.cwl/gtf_file"
                },
                {
                    "type": "string",
                    "default": "None",
                    "inputBinding": {
                        "position": 6,
                        "prefix": "--outReadsUnmapped"
                    },
                    "id": "#star_align_fusion.cwl/out_reads_unmapped"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "default": [
                        "BAM",
                        "Unsorted"
                    ],
                    "inputBinding": {
                        "position": 3,
                        "prefix": "--outSAMtype"
                    },
                    "id": "#star_align_fusion.cwl/out_samtype"
                },
                {
                    "type": "string",
                    "default": "STAR_",
                    "inputBinding": {
                        "position": 25,
                        "prefix": "--outFileNamePrefix"
                    },
                    "id": "#star_align_fusion.cwl/outfile_name_prefix"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "default": [
                        "NH",
                        "HI",
                        "AS",
                        "NM",
                        "MD"
                    ],
                    "inputBinding": {
                        "position": 27,
                        "prefix": "--outSAMattributes",
                        "itemSeparator": " ",
                        "shellQuote": false
                    },
                    "id": "#star_align_fusion.cwl/outsam_attributes"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "inputBinding": {
                        "position": 16,
                        "itemSeparator": " , ",
                        "shellQuote": false,
                        "prefix": "--outSAMattrRGline"
                    },
                    "doc": " string(s): SAM/BAM read group line. The first word contains the read group identifier and must start with ID:, e.g. \u2013outSAMattrRGline ID:xxx CN:yy DS:z z z. xxx will be added as RG tag to each output alignment. Any spaces in the tag values have to be double quoted. Comma separated RG lines correspons to different (comma separated) input files in \u2013readFilesIn ",
                    "id": "#star_align_fusion.cwl/outsam_attrrg_line"
                },
                {
                    "type": "string",
                    "default": "intronMotif",
                    "inputBinding": {
                        "position": 14,
                        "prefix": "--outSAMstrandField"
                    },
                    "id": "#star_align_fusion.cwl/outsam_strand_field"
                },
                {
                    "type": "string",
                    "default": "Within",
                    "inputBinding": {
                        "position": 15,
                        "prefix": "--outSAMunmapped"
                    },
                    "id": "#star_align_fusion.cwl/outsam_unmapped"
                },
                {
                    "type": "float",
                    "default": 0.1,
                    "inputBinding": {
                        "position": 20,
                        "prefix": "--peOverlapMMp"
                    },
                    "id": "#star_align_fusion.cwl/peoverlap_mmp"
                },
                {
                    "type": "int",
                    "default": 12,
                    "inputBinding": {
                        "position": 19,
                        "prefix": "--peOverlapNbasesMin"
                    },
                    "id": "#star_align_fusion.cwl/peoverlap_nbases_min"
                },
                {
                    "default": "cat",
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 26,
                        "prefix": "--readFilesCommand"
                    },
                    "id": "#star_align_fusion.cwl/read_files_command"
                },
                {
                    "type": "string",
                    "default": "alignReads",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--runMode"
                    },
                    "id": "#star_align_fusion.cwl/run_mode"
                },
                {
                    "type": "Directory",
                    "inputBinding": {
                        "position": 22,
                        "prefix": "--genomeDir"
                    },
                    "doc": " specifies path to the directory where the genome indices are stored ",
                    "id": "#star_align_fusion.cwl/star_genome_dir"
                },
                {
                    "type": "string",
                    "default": "Basic",
                    "inputBinding": {
                        "position": 23,
                        "prefix": "--twopassMode"
                    },
                    "id": "#star_align_fusion.cwl/twopass_mode"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.outfile_name_prefix)Aligned.out.bam"
                    },
                    "id": "#star_align_fusion.cwl/aligned_bam"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.outfile_name_prefix)Chimeric.out.junction"
                    },
                    "id": "#star_align_fusion.cwl/chim_junc"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.outfile_name_prefix)Log.out"
                    },
                    "id": "#star_align_fusion.cwl/log"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.outfile_name_prefix)Log.final.out"
                    },
                    "id": "#star_align_fusion.cwl/log_final"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.outfile_name_prefix)Log.progress.out"
                    },
                    "id": "#star_align_fusion.cwl/log_progress"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.outfile_name_prefix)SJ.out.tab"
                    },
                    "id": "#star_align_fusion.cwl/splice_junction_out"
                }
            ],
            "id": "#star_align_fusion.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "STAR-Fusion identify candidate fusion transcript",
            "baseCommand": [
                "/usr/local/src/STAR-Fusion/STAR-Fusion"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 64000,
                    "coresMin": 10
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "trinityctat/starfusion:1.8.0"
                }
            ],
            "arguments": [
                "--CPU",
                "$(runtime.cores)"
            ],
            "inputs": [
                {
                    "type": "string",
                    "default": "STAR-Fusion_outdir",
                    "inputBinding": {
                        "prefix": "--output_dir",
                        "position": 4
                    },
                    "id": "#star_fusion_detect.cwl/fusion_output_dir"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-J",
                        "position": 3
                    },
                    "id": "#star_fusion_detect.cwl/junction_file"
                },
                {
                    "type": "Directory",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--genome_lib_dir"
                    },
                    "doc": " fusion genome dir directory containing genome lib (see http://STAR-Fusion.github.io) ",
                    "id": "#star_fusion_detect.cwl/star_fusion_genome_dir"
                },
                {
                    "type": "string",
                    "default": "/usr/local/bin/STAR",
                    "inputBinding": {
                        "prefix": "--STAR_PATH",
                        "position": 5
                    },
                    "id": "#star_fusion_detect.cwl/star_path"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.fusion_output_dir +\"/star-fusion.fusion_predictions.abridged.tsv\")"
                    },
                    "id": "#star_fusion_detect.cwl/fusion_abridged"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.fusion_output_dir +\"/star-fusion.fusion_predictions.tsv\")"
                    },
                    "id": "#star_fusion_detect.cwl/fusion_predictions"
                }
            ],
            "id": "#star_fusion_detect.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "runs how_are_we_stranded_here to determine RNAseq data strandedness",
            "doc": "Uses how_are_we_stranded_here, a python package for testing strandedness. Runs Kallisto and Rseqc (infer-experiment-py) to\nto check which direction reads align once mapped in transcripts. It first creates a Kallisto index (or uses a pre-made index)\nof your organism's transcriptome. It then maps a small subset of reads (default 200000) to the transcriptome and uses Kallisto's\n--genomebam argument to project pseudoalignments to the genome sorted BAM file. (Currently only Kallisto version 0.44.0 works well with\nhow_are_we_stranded_here.) It finally runs RSeQC's infer_experiment.py to check which direction reads from the first and second pairs\nare aligned in relation to the transcript strand, and provides output with the likely strandedness of your data.\n",
            "baseCommand": [
                "check_strandedness"
            ],
            "arguments": [
                "--print_commands"
            ],
            "stdout": "$(inputs.reads1.nameroot).strandness_check.txt",
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000,
                    "tmpdirMin": 5000,
                    "coresMin": 1
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/checkstrandedness:v1"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--transcripts"
                    },
                    "id": "#strandedness_check.cwl/cdna_fasta"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--gtf"
                    },
                    "id": "#strandedness_check.cwl/gtf_file"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--kallisto_index"
                    },
                    "id": "#strandedness_check.cwl/kallisto_index"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--reads_1"
                    },
                    "id": "#strandedness_check.cwl/reads1"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--reads_2"
                    },
                    "id": "#strandedness_check.cwl/reads2"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#strandedness_check.cwl/strandedness_check",
                    "outputBinding": {
                        "glob": "$(inputs.reads1.nameroot).strandness_check.txt"
                    }
                }
            ],
            "id": "#strandedness_check.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "StringTie",
            "baseCommand": [
                "/usr/local/bin/stringtie"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000,
                    "coresMin": 12
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/biocontainers/stringtie:2.1.4--h7e0af3c_0"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "arguments": [
                "-o",
                "$(runtime.outdir)/stringtie_transcripts.gtf",
                "-A",
                "$(runtime.outdir)/stringtie_gene_expression.tsv",
                "-p",
                "$(runtime.cores)",
                "-e"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#stringtie.cwl/bam"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-G",
                        "position": 2
                    },
                    "id": "#stringtie.cwl/reference_annotation"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-l",
                        "position": 3
                    },
                    "id": "#stringtie.cwl/sample_name"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#stringtie.cwl/strand/first",
                                "#stringtie.cwl/strand/second",
                                "#stringtie.cwl/strand/unstranded"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "valueFrom": "${\n    if (inputs.strand) {\n        if (inputs.strand == 'first') {\n            return ['--rf'];\n        } else if (inputs.strand == 'second') {\n            return ['--fr'];\n        } else {\n            return [];\n        }\n    } else {\n            return []\n    }\n}\n",
                        "position": 1
                    },
                    "id": "#stringtie.cwl/strand"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "stringtie_gene_expression.tsv"
                    },
                    "id": "#stringtie.cwl/gene_expression_tsv"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "stringtie_transcripts.gtf"
                    },
                    "id": "#stringtie.cwl/transcript_gtf"
                }
            ],
            "id": "#stringtie.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Kallisto: TranscriptToGene",
            "baseCommand": [
                "/usr/local/bin/Rscript"
            ],
            "arguments": [
                "/usr/src/transcript_to_gene.R"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 2000,
                    "coresMin": 1
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/rnaseq:1.0.0"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#transcript_to_gene.cwl/gene_transcript_lookup_table"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#transcript_to_gene.cwl/transcript_table_h5"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "gene_abundance.tsv"
                    },
                    "id": "#transcript_to_gene.cwl/gene_abundance"
                }
            ],
            "id": "#transcript_to_gene.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Trim FASTQ (flexbar)",
            "baseCommand": [
                "/opt/flexbar/flexbar"
            ],
            "arguments": [
                "--target",
                {
                    "valueFrom": "$(runtime.outdir)/trimmed_read"
                },
                "--threads",
                {
                    "valueFrom": "$(runtime.cores)"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000,
                    "tmpdirMin": 25000,
                    "coresMin": 4
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/bisulfite:v1.4"
                }
            ],
            "inputs": [
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "--adapter-min-overlap",
                        "position": 3
                    },
                    "id": "#trim_fastq.cwl/adapter_min_overlap"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--adapter-trim-end",
                        "position": 2
                    },
                    "id": "#trim_fastq.cwl/adapter_trim_end"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--adapters",
                        "position": 1
                    },
                    "id": "#trim_fastq.cwl/adapters"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "--max-uncalled",
                        "position": 5
                    },
                    "id": "#trim_fastq.cwl/max_uncalled"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "--min-read-length",
                        "position": 6
                    },
                    "id": "#trim_fastq.cwl/min_readlength"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--reads",
                        "position": 7
                    },
                    "id": "#trim_fastq.cwl/reads1"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--reads2",
                        "position": 8
                    },
                    "id": "#trim_fastq.cwl/reads2"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "trimmed_read_1.fastq"
                    },
                    "id": "#trim_fastq.cwl/fastq1"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "trimmed_read_2.fastq"
                    },
                    "id": "#trim_fastq.cwl/fastq2"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "trimmed_read_*.fastq"
                    },
                    "id": "#trim_fastq.cwl/fastqs"
                }
            ],
            "id": "#trim_fastq.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
